@@ -41,6 +41,7 @@ pub mod strings;
 #[cfg(feature = "temporal")]
 #[cfg_attr(docsrs, doc(cfg(feature = "temporal")))]
 pub mod temporal;
+mod trusted_len;
 pub mod upstream_traits;
 
 use arrow::array::{
@@ -152,9 +153,30 @@ pub struct ChunkedArray<T> {
     phantom: PhantomData<T>,
     /// maps categorical u32 indexes to String values
     pub(crate) categorical_map: Option<Arc<RevMapping>>,
+    // first bit: sorted
+    // second_bit: sorted reverse
+    pub(crate) bit_settings: u8,
 }
 
 impl<T> ChunkedArray<T> {
+    #[cfg(feature = "asof_join")]
+    pub(crate) fn is_sorted(&self) -> bool {
+        self.bit_settings & 1 != 0
+    }
+
+    #[cfg(feature = "asof_join")]
+    pub(crate) fn is_sorted_reverse(&self) -> bool {
+        self.bit_settings & 1 << 1 != 0
+    }
+
+    pub(crate) fn set_sorted(&mut self, reverse: bool) {
+        if reverse {
+            self.bit_settings |= 1 << 1
+        } else {
+            self.bit_settings |= 1
+        }
+    }
+
     /// Get Arrow ArrayData
     pub fn array_data(&self) -> Vec<&ArrayData> {
         self.chunks.iter().map(|arr| arr.data()).collect()
@@ -203,10 +225,16 @@ impl<T> ChunkedArray<T> {
 
     /// Shrink the capacity of this array to fit it's length.
     pub fn shrink_to_fit(&mut self) {
-        self.chunks = vec![arrow::compute::concat(
-            &self.chunks.iter().map(|a| &**a).collect_vec().as_slice(),
-        )
-        .unwrap()];
+        if self.chunks.len() == 1 {
+            self.chunks = vec![polars_arrow::kernels::shrink_to_fit::shrink_to_fit(
+                &*self.chunks[0],
+            )]
+        }
+        self.chunks =
+            vec![
+                arrow::compute::concat(self.chunks.iter().map(|a| &**a).collect_vec().as_slice())
+                    .unwrap(),
+            ];
     }
 
     /// Unpack a Series to the same physical type.
@@ -333,6 +361,7 @@ impl<T> ChunkedArray<T> {
             chunks,
             phantom: PhantomData,
             categorical_map: self.categorical_map.clone(),
+            ..Default::default()
         }
     }
 
@@ -515,6 +544,7 @@ where
             chunks,
             phantom: PhantomData,
             categorical_map: None,
+            bit_settings: 0,
         }
     }
 
@@ -571,10 +601,10 @@ where
                 AnyValue::List(s.unwrap())
             }
             #[cfg(feature = "object")]
-            DataType::Object(_) => AnyValue::Object(&"object"),
+            DataType::Object(_) => AnyValue::Object("object"),
             DataType::Categorical => {
                 let v = downcast!(UInt32Array);
-                AnyValue::Utf8(&self.categorical_map.as_ref().expect("should be set").get(v))
+                AnyValue::Utf8(self.categorical_map.as_ref().expect("should be set").get(v))
             }
             _ => unimplemented!(),
         }
@@ -603,6 +633,7 @@ where
             chunks: vec![arr],
             phantom: PhantomData,
             categorical_map: None,
+            ..Default::default()
         }
     }
 }
@@ -659,8 +690,13 @@ where
     #[allow(clippy::wrong_self_convention)]
     pub fn into_no_null_iter(
         &self,
-    ) -> impl Iterator<Item = T::Native> + '_ + Send + Sync + ExactSizeIterator + DoubleEndedIterator
-    {
+    ) -> impl Iterator<Item = T::Native>
+           + '_
+           + Send
+           + Sync
+           + ExactSizeIterator
+           + DoubleEndedIterator
+           + TrustedLen {
         // .copied was significantly slower in benchmark, next call did not inline?
         #[allow(clippy::map_clone)]
         self.data_views()
@@ -771,6 +807,7 @@ impl<T> Clone for ChunkedArray<T> {
             chunks: self.chunks.clone(),
             phantom: PhantomData,
             categorical_map: self.categorical_map.clone(),
+            ..Default::default()
         }
     }
 }
@@ -1045,6 +1082,7 @@ pub(crate) mod test {
             .iter()
             .map(|arr| arr.get_buffer_memory_size())
             .sum::<usize>();
+        dbg!(before, after);
         assert!(before > after);
     }
 }
