@@ -35,6 +35,17 @@ pub(crate) mod window;
 #[cfg(feature = "zip_with")]
 pub(crate) mod zip;
 
+#[cfg(feature = "reinterpret")]
+pub trait Reinterpret {
+    fn reinterpret_signed(&self) -> Series {
+        unimplemented!()
+    }
+
+    fn reinterpret_unsigned(&self) -> Series {
+        unimplemented!()
+    }
+}
+
 /// Transmute ChunkedArray to bit representation.
 /// This is useful in hashing context and reduces no.
 /// of compiled code paths.
@@ -606,6 +617,15 @@ pub trait ChunkUnique<T> {
             "is_duplicated is not implemented for this dtype".into(),
         ))
     }
+
+    /// The most occurring value(s). Can return multiple Values
+    #[cfg(feature = "mode")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "mode")))]
+    fn mode(&self) -> Result<ChunkedArray<T>> {
+        Err(PolarsError::InvalidOperation(
+            "mode is not implemented for this dtype".into(),
+        ))
+    }
 }
 
 pub trait ToDummies<T>: ChunkUnique<T> {
