@@ -3,12 +3,14 @@ use crate::chunked_array::builder::get_list_builder;
 #[cfg(feature = "object")]
 use crate::chunked_array::object::ObjectArray;
 use crate::prelude::*;
+use crate::utils::arrow::buffer::MutableBuffer;
 use crate::utils::NoNull;
 use crate::utils::{get_iter_capacity, CustomIterTools};
-use arrow::array::{BooleanArray, LargeStringArray, PrimitiveArray};
+use arrow::array::{ArrayData, BooleanArray, LargeStringArray, PrimitiveArray};
+use arrow::buffer::Buffer;
 #[cfg(feature = "object")]
 use polars_arrow::prelude::BooleanBufferBuilder;
-use polars_arrow::utils::TrustMyLength;
+use polars_arrow::trusted_len::trusted_len_unzip_extend;
 use rayon::iter::{FromParallelIterator, IntoParallelIterator};
 use rayon::prelude::*;
 use std::borrow::{Borrow, Cow};
@@ -24,6 +26,7 @@ impl<T> Default for ChunkedArray<T> {
             chunks: Default::default(),
             phantom: PhantomData,
             categorical_map: None,
+            bit_settings: 0,
         }
     }
 }
@@ -71,11 +74,25 @@ where
     // We use AlignedVec because it is way faster than Arrows builder. We can do this because we
     // know we don't have null values.
     fn from_iter<I: IntoIterator<Item = T::Native>>(iter: I) -> Self {
-        // 2021-02-07: aligned vec was ~2x faster than arrow collect.
         let iter = iter.into_iter();
-        let mut av = AlignedVec::with_capacity_aligned(0);
-        av.extend(iter);
-        NoNull::new(ChunkedArray::new_from_aligned_vec("", av))
+        #[cfg(feature = "performant")]
+        {
+            let len = iter.size_hint().0;
+            let buffer = unsafe { Buffer::from_trusted_len_iter(iter) };
+
+            let data = ArrayData::new(T::DATA_TYPE, len, None, None, 0, vec![buffer], vec![]);
+            NoNull::new(ChunkedArray::new_from_chunks(
+                "",
+                vec![Arc::new(PrimitiveArray::<T>::from(data))],
+            ))
+        }
+        #[cfg(not(feature = "performant"))]
+        {
+            // 2021-02-07: aligned vec was ~2x faster than arrow collect.
+            let mut av = AlignedVec::with_capacity_aligned(0);
+            av.extend(iter);
+            NoNull::new(ChunkedArray::new_from_aligned_vec("", av))
+        }
     }
 }
 
@@ -192,7 +209,7 @@ where
         }
 
         // now the first non None
-        builder.append_series(&v);
+        builder.append_series(v);
 
         // now we have added all Nones, we can consume the rest of the iterator.
         for opt_s in it {
@@ -249,6 +266,7 @@ impl<T: PolarsObject> FromIterator<Option<T>> for ObjectChunked<T> {
             chunks: vec![arr],
             phantom: PhantomData,
             categorical_map: None,
+            bit_settings: 0,
         }
     }
 }
@@ -322,9 +340,16 @@ where
         let vectors = collect_into_linked_list(iter);
 
         let capacity: usize = get_capacity_from_par_results(&vectors);
+        // zeroed immediately correct for nulls
+        let mut validity = MutableBuffer::from_len_zeroed(capacity.saturating_add(7) / 8);
+        let mut values = AlignedVec::with_capacity_aligned(capacity);
 
-        let iter = TrustMyLength::new(vectors.into_iter().flatten(), capacity);
-        let arr: PrimitiveArray<T> = unsafe { PrimitiveArray::from_trusted_len_iter(iter) };
+        for vec in vectors {
+            // Safety:
+            // vec's length can be trusted
+            unsafe { trusted_len_unzip_extend(vec.into_iter(), &mut values, &mut validity) }
+        }
+        let arr: PrimitiveArray<T> = values.into_primitive_array(Some(validity.into()));
         Self::new_from_chunks("", vec![Arc::new(arr)])
     }
 }
