@@ -62,6 +62,10 @@ pub enum JoinType {
     Left,
     Inner,
     Outer,
+    #[cfg(feature = "asof_join")]
+    AsOf,
+    #[cfg(feature = "cross_join")]
+    Cross,
 }
 
 unsafe fn get_hash_tbl_threaded_join_partitioned<T, H>(
@@ -339,7 +343,7 @@ fn probe_outer<T, F, G, H>(
 
             let entry = current_probe_table
                 .raw_entry_mut()
-                .from_key_hashed_nocheck(h, &key);
+                .from_key_hashed_nocheck(h, key);
 
             match entry {
                 // match and remove
@@ -649,7 +653,7 @@ where
                 let other: &UInt64Chunked = unsafe {
                     &*(other as *const ChunkedArray<T> as *const ChunkedArray<UInt64Type>)
                 };
-                num_group_join_inner(&ca, &other)
+                num_group_join_inner(ca, other)
             }
             DataType::UInt32 => {
                 // convince the compiler that we are this type.
@@ -659,7 +663,7 @@ where
                 let other: &UInt32Chunked = unsafe {
                     &*(other as *const ChunkedArray<T> as *const ChunkedArray<UInt32Type>)
                 };
-                num_group_join_inner(&ca, &other)
+                num_group_join_inner(ca, other)
             }
             DataType::Int64 | DataType::Float64 => {
                 let ca = self.bit_repr_large();
@@ -689,7 +693,7 @@ where
                 let other: &UInt64Chunked = unsafe {
                     &*(other as *const ChunkedArray<T> as *const ChunkedArray<UInt64Type>)
                 };
-                num_group_join_left(&ca, &other)
+                num_group_join_left(ca, other)
             }
             DataType::UInt32 => {
                 // convince the compiler that we are this type.
@@ -699,7 +703,7 @@ where
                 let other: &UInt32Chunked = unsafe {
                     &*(other as *const ChunkedArray<T> as *const ChunkedArray<UInt32Type>)
                 };
-                num_group_join_left(&ca, &other)
+                num_group_join_left(ca, other)
             }
             DataType::Int64 | DataType::Float64 => {
                 let ca = self.bit_repr_large();
@@ -947,7 +951,11 @@ impl_zip_outer_join!(Utf8Chunked);
 
 impl DataFrame {
     /// Utility method to finish a join.
-    fn finish_join(&self, mut df_left: DataFrame, mut df_right: DataFrame) -> Result<DataFrame> {
+    pub(crate) fn finish_join(
+        &self,
+        mut df_left: DataFrame,
+        mut df_right: DataFrame,
+    ) -> Result<DataFrame> {
         let mut left_names = HashSet::with_capacity_and_hasher(df_left.width(), RandomState::new());
 
         df_left.columns.iter().for_each(|series| {
@@ -988,6 +996,11 @@ impl DataFrame {
         right_on: S2,
         how: JoinType,
     ) -> Result<DataFrame> {
+        #[cfg(feature = "cross_join")]
+        if let JoinType::Cross = how {
+            return self.cross_join(other);
+        }
+
         let selected_left = self.select_series(left_on)?;
         let selected_right = other.select_series(right_on)?;
         assert_eq!(selected_right.len(), selected_left.len());
@@ -1007,6 +1020,14 @@ impl DataFrame {
                 JoinType::Outer => {
                     self.outer_join(other, selected_left[0].name(), selected_right[0].name())
                 }
+                #[cfg(feature = "asof_join")]
+                JoinType::AsOf => {
+                    self.join_asof(other, selected_left[0].name(), selected_right[0].name())
+                }
+                #[cfg(feature = "cross_join")]
+                JoinType::Cross => {
+                    unreachable!()
+                }
             };
         }
 
@@ -1096,6 +1117,14 @@ impl DataFrame {
                 }
                 self.finish_join(df_left, df_right)
             }
+            #[cfg(feature = "asof_join")]
+            JoinType::AsOf => Err(PolarsError::ValueError(
+                "asof join not supported for join on multiple keys".into(),
+            )),
+            #[cfg(feature = "cross_join")]
+            JoinType::Cross => {
+                unreachable!()
+            }
         }
     }
 
@@ -1250,6 +1279,7 @@ mod test {
     }
 
     #[test]
+    #[cfg_attr(miri, ignore)]
     fn test_inner_join() {
         let (temp, rain) = create_frames();
 
@@ -1276,6 +1306,7 @@ mod test {
 
     #[test]
     #[allow(clippy::float_cmp)]
+    #[cfg_attr(miri, ignore)]
     fn test_left_join() {
         for i in 1..8 {
             std::env::set_var("POLARS_MAX_THREADS", format!("{}", i));
@@ -1313,6 +1344,7 @@ mod test {
     }
 
     #[test]
+    #[cfg_attr(miri, ignore)]
     fn test_outer_join() -> Result<()> {
         let (temp, rain) = create_frames();
         let joined = temp.outer_join(&rain, "days", "days")?;
@@ -1338,6 +1370,7 @@ mod test {
     }
 
     #[test]
+    #[cfg_attr(miri, ignore)]
     fn test_join_with_nulls() {
         let dts = &[20, 21, 22, 23, 24, 25, 27, 28];
         let vals = &[1.2, 2.4, 4.67, 5.8, 4.4, 3.6, 7.6, 6.5];
@@ -1380,6 +1413,7 @@ mod test {
     }
 
     #[test]
+    #[cfg_attr(miri, ignore)]
     fn test_join_multiple_columns() {
         let (df_a, df_b) = get_dfs();
 
@@ -1452,6 +1486,7 @@ mod test {
     }
 
     #[test]
+    #[cfg_attr(miri, ignore)]
     fn test_join_categorical() {
         let _lock = crate::SINGLE_LOCK.lock();
         toggle_string_cache(true);
@@ -1493,6 +1528,7 @@ mod test {
     }
 
     #[test]
+    #[cfg_attr(miri, ignore)]
     fn empty_df_join() {
         let empty: Vec<String> = vec![];
         let left = DataFrame::new(vec![
