@@ -19,6 +19,8 @@ use crate::prelude::*;
 use ahash::RandomState;
 use arrow::array::{ArrayData, ArrayRef};
 use arrow::buffer::Buffer;
+#[cfg(feature = "object")]
+use std::any::Any;
 use std::borrow::Cow;
 
 impl<T> ChunkedArray<T> {
@@ -105,6 +107,15 @@ macro_rules! impl_dyn_series {
         }
 
         impl private::PrivateSeries for SeriesWrap<$ca> {
+            #[cfg(feature = "asof_join")]
+            fn join_asof(&self, other: &Series) -> Result<Vec<Option<u32>>> {
+                cast_and_apply!(self, join_asof, other)
+            }
+
+            fn set_sorted(&mut self, reverse: bool) {
+                self.0.set_sorted(reverse)
+            }
+
             unsafe fn equal_element(
                 &self,
                 idx_self: usize,
@@ -705,6 +716,19 @@ macro_rules! impl_dyn_series {
             fn repeat_by(&self, by: &UInt32Chunked) -> ListChunked {
                 RepeatBy::repeat_by(&self.0, by)
             }
+            #[cfg(feature = "is_first")]
+            fn is_first(&self) -> Result<BooleanChunked> {
+                cast_and_apply!(self, is_first,)
+            }
+
+            #[cfg(feature = "object")]
+            fn as_any(&self) -> &dyn Any {
+                &self.0
+            }
+            #[cfg(feature = "mode")]
+            fn mode(&self) -> Result<Series> {
+                try_physical_dispatch!(self, mode,)
+            }
         }
     };
 }
@@ -765,6 +789,7 @@ mod test {
 
     #[test]
     #[cfg(feature = "dtype-date64")]
+    #[cfg_attr(miri, ignore)]
     fn test_datelike_join() -> Result<()> {
         let s = Series::new("foo", &[1, 2, 3]);
         let mut s1 = s.cast_with_dtype(&DataType::Date64)?;
