@@ -8,6 +8,8 @@
 pub mod dates;
 #[cfg(feature = "object")]
 pub mod object;
+#[cfg(feature = "object")]
+use std::any::Any;
 
 use super::private;
 use super::IntoSeries;
@@ -16,11 +18,13 @@ use crate::chunked_array::comparison::*;
 use crate::chunked_array::{
     ops::{
         aggregate::{ChunkAggSeries, VarAggSeries},
-        compare_inner::{IntoPartialEqInner, PartialEqInner},
+        compare_inner::{IntoPartialEqInner, IntoPartialOrdInner, PartialEqInner, PartialOrdInner},
     },
     AsSinglePtr, ChunkIdIter,
 };
 use crate::fmt::FmtList;
+#[cfg(feature = "asof_join")]
+use crate::frame::asof_join::JoinAsof;
 #[cfg(feature = "pivot")]
 use crate::frame::groupby::pivot::*;
 use crate::frame::groupby::*;
@@ -60,6 +64,15 @@ macro_rules! impl_dyn_series {
         }
 
         impl private::PrivateSeries for SeriesWrap<$ca> {
+            #[cfg(feature = "asof_join")]
+            fn join_asof(&self, other: &Series) -> Result<Vec<Option<u32>>> {
+                self.0.join_asof(other.as_ref().as_ref())
+            }
+
+            fn set_sorted(&mut self, reverse: bool) {
+                self.0.set_sorted(reverse)
+            }
+
             unsafe fn equal_element(
                 &self,
                 idx_self: usize,
@@ -77,6 +90,9 @@ macro_rules! impl_dyn_series {
             fn into_partial_eq_inner<'a>(&'a self) -> Box<dyn PartialEqInner + 'a> {
                 (&self.0).into_partial_eq_inner()
             }
+            fn into_partial_ord_inner<'a>(&'a self) -> Box<dyn PartialOrdInner + 'a> {
+                (&self.0).into_partial_ord_inner()
+            }
 
             fn vec_hash(&self, random_state: RandomState) -> AlignedVec<u64> {
                 self.0.vec_hash(random_state)
@@ -849,6 +865,20 @@ macro_rules! impl_dyn_series {
             fn checked_div(&self, rhs: &Series) -> Result<Series> {
                 self.0.checked_div(rhs)
             }
+
+            #[cfg(feature = "is_first")]
+            fn is_first(&self) -> Result<BooleanChunked> {
+                self.0.is_first()
+            }
+
+            #[cfg(feature = "object")]
+            fn as_any(&self) -> &dyn Any {
+                &self.0
+            }
+            #[cfg(feature = "mode")]
+            fn mode(&self) -> Result<Series> {
+                Ok(self.0.mode()?.into_series())
+            }
         }
     };
 }
